import 'dart:async';
import 'package:flutter/services.dart';

const EventChannel _ppgEventChannel = EventChannel('ppg');
const EventChannel _hrEventChannel = EventChannel('hr');

class PPGEvent {
  PPGEvent(List<double> event)
      : x = event.sublist(0, event.length - 1),
        t = event[event.length - 2],
        accuracy = event.last.toInt();
  final List<double> x;
  final double t;
  final int accuracy;
  @override
  String toString() => '[PPGEvent (x: $x, t: $t, accuracy: $accuracy)]';
}

class HREvent {
  HREvent(List<double> event)
      : x = event.first,
        t = event[event.length - 2],
        accuracy = event.last.toInt();
  final double x, t;
  final int accuracy;
  @override
  String toString() => '[HREvent (x: $x, t: $t, accuracy: $accuracy)]';
}

Stream<PPGEvent> get ppgEvents => _ppgEventChannel
    .receiveBroadcastStream()
    .map((event) => PPGEvent(event.cast<double>()));

Stream<HREvent> get hrEvents => _hrEventChannel
    .receiveBroadcastStream()
    .map((event) => HREvent(event.cast<double>()));
